@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -39,4 +37,4 @@ class FrozenMachine(AutomatonException):
     """Exception raised when a frozen machine is modified."""
 
     def __init__(self):
-        super(FrozenMachine, self).__init__("Frozen machine can't be modified")
+        super().__init__("Frozen machine can't be modified")
